@@ -48,7 +48,7 @@ ExpandAnimationButton::ExpandAnimationButton(QWidget *parent) : QWidget(parent)
 
 void ExpandAnimationButton::startAnimation()
 {
-    renderTimer = new QTimer();
+    renderTimer = new QTimer(this);
     connect(renderTimer, SIGNAL(timeout()), this, SLOT(renderAnimation()));
     renderTimer->start(animationDuration);
 }
