@@ -54,18 +54,18 @@ FileView::FileView(QWidget *parent) : QListWidget(parent)
             emit play(fileItem->getRecodingFilepath());
         });
 
-    rightMenu = new QMenu();
+    rightMenu = new QMenu(this);
     renameAction = new QAction(tr("Rename"), this);
     connect(renameAction, &QAction::triggered, this, &FileView::renameItem);
     displayAction = new QAction(tr("Display in file manager"), this);
     connect(displayAction, &QAction::triggered, this, &FileView::displayItem);
-    trashAction = new QAction(tr("Move to trash"), this);
+    trashAction = new QAction(tr("Delete"), this);
     connect(trashAction, &QAction::triggered, this, &FileView::trashItem);
     rightMenu->addAction(renameAction);
     rightMenu->addAction(displayAction);
     rightMenu->addAction(trashAction);
 
-    fileWatcher = new QFileSystemWatcher();
+    fileWatcher = new QFileSystemWatcher(this);
     fileWatcher->addPath(Utils::getRecordingSaveDirectory());
     connect(fileWatcher, &QFileSystemWatcher::directoryChanged, this, &FileView::monitorFileChanged);
 
@@ -74,7 +74,7 @@ FileView::FileView(QWidget *parent) : QListWidget(parent)
 
 void FileView::loadItem(QString item)
 {
-    FileItem *fileItem = new FileItem();
+    FileItem *fileItem = new FileItem(this);
     fileItem->setFileInfo(QFileInfo(item));
     connect(fileItem, SIGNAL(play()), this, SLOT(handlePlay()));
     connect(fileItem, SIGNAL(pause()), this, SLOT(handlePause()));
@@ -82,9 +82,11 @@ void FileView::loadItem(QString item)
     connect(fileItem, SIGNAL(stop()), this, SLOT(handleStop()));
     connect(fileItem, SIGNAL(enter()), this, SLOT(handleEnter()));
 
-    addItem(fileItem->getItem());
-    fileItem->getItem()->setSizeHint(QSize(100, 60));
-    setItemWidget(fileItem->getItem(), fileItem);
+    QListWidgetItem* listItem = new QListWidgetItem;
+
+    addItem(listItem);
+    listItem->setSizeHint(QSize(100, 60));
+    setItemWidget(listItem, fileItem);
 }
 
 void FileView::loadItems(QStringList sortedItems, int scrollValue)
@@ -97,24 +99,24 @@ void FileView::loadItems(QStringList sortedItems, int scrollValue)
 
     foreach (auto fileInfo, Utils::getRecordingFileinfos()) {
         QString filepath = fileInfo.absoluteFilePath();
-        
+
         if (!sortedItems.contains(filepath)) {
             sortedItems.removeOne(filepath);
             otherItems << filepath;
         }
     }
-    
+
     foreach (auto item, sortedItems) {
         // Just restore when old item filepath exist.
         if (Utils::fileExists(item)) {
             loadItem(item);
         }
     }
-    
+
     foreach (auto item, otherItems) {
         loadItem(item);
     }
-    
+
     // Restore scroll value.
     verticalScrollBar()->setValue(scrollValue);
 }
@@ -135,7 +137,7 @@ void FileView::monitorFileChanged(QString)
 
         sortedItems << fileItem->getRecodingFilepath();
     }
-    
+
     loadItems(sortedItems, verticalScrollBar()->value());
 
     monitorList();
