@@ -2,68 +2,40 @@
 <context>
     <name>FileView</name>
     <message>
-        <location filename="../src/file_view.cpp" line="59"/>
+        <location filename="../src/file_view.cpp" line="58"/>
         <source>Rename</source>
         <translation>Преименуј</translation>
     </message>
     <message>
-        <location filename="../src/file_view.cpp" line="61"/>
+        <location filename="../src/file_view.cpp" line="60"/>
         <source>Display in file manager</source>
         <translation>Прикажи у управнику података</translation>
     </message>
     <message>
-        <location filename="../src/file_view.cpp" line="63"/>
-        <source>Move to trash</source>
-        <translation>Премести у смеће</translation>
+        <location filename="../src/file_view.cpp" line="62"/>
+        <source>Delete</source>
+        <translation>Обриши</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/main_window.cpp" line="53"/>
+        <location filename="../src/main_window.cpp" line="50"/>
         <source>New recording</source>
         <translation>Нови снимак</translation>
     </message>
     <message>
-        <location filename="../src/main_window.cpp" line="55"/>
+        <location filename="../src/main_window.cpp" line="52"/>
         <source>Open saved directory</source>
         <translation>Отвори место чувања</translation>
     </message>
     <message>
-        <location filename="../src/main_window.cpp" line="57"/>
-        <source>About</source>
-        <translation>О програму</translation>
-    </message>
-    <message>
-        <location filename="../src/main_window.cpp" line="59"/>
-        <source>Help</source>
-        <translation>Помоћ</translation>
-    </message>
-    <message>
-        <location filename="../src/main_window.cpp" line="61"/>
-        <source>Exit</source>
-        <translation>Изађи</translation>
-    </message>
-    <message>
-        <location filename="../src/main_window.cpp" line="168"/>
-        <source>Deepin Voice Recorder is a beautiful and easy to use voice recording application with simple design. It supports visual recording, recording playback, recording list management and other functions.</source>
+        <location filename="../src/main.cpp" line="41"/>
+        <source>Deepin Voice Recorder is a simple, beautiful and easy to use voice recording application. It supports visual recording, playback, recordings management and other functions.</source>
         <translation>Дипин Снимач Гласа је леп и лак за коришћење програм једноставног дизајна. Подржава визуелно снимање, пуштање снимка, управљање листом снимака и друге функције.</translation>
     </message>
     <message>
-        <location filename="../src/main_window.cpp" line="180"/>
-        <source>Deepin Voice Recorder</source>
-        <translation>Дипин Снимач Гласа</translation>
-    </message>
-    <message>
-        <location filename="../src/main_window.cpp" line="181"/>
-        <source>Version</source>
-        <translation>Верзија</translation>
-    </message>
-</context>
-<context>
-    <name>QObject</name>
-    <message>
-        <location filename="../src/main.cpp" line="45"/>
+        <location filename="../src/main.cpp" line="59"/>
         <source>Deepin Voice Recorder</source>
         <translation>Дипин Снимач Гласа</translation>
     </message>
@@ -71,8 +43,8 @@
 <context>
     <name>RecordPage</name>
     <message>
-        <location filename="../src/record_page.cpp" line="55"/>
-        <location filename="../src/record_page.cpp" line="219"/>
+        <location filename="../src/record_page.cpp" line="59"/>
+        <location filename="../src/record_page.cpp" line="234"/>
         <source>New recording</source>
         <translation>Нови снимак</translation>
     </message>
@@ -81,8 +53,8 @@
     <name>Utils</name>
     <message>
         <location filename="../src/utils.cpp" line="136"/>
-        <source>Recording</source>
-        <translation>Снимање</translation>
+        <source>Recordings</source>
+        <translation>Снимци</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
